@@ -6,7 +6,7 @@ import threading
 from openrgb import utils
 from typing import Callable
 
-OPENRGB_PROTOCOL_VERSION = 1
+OPENRGB_PROTOCOL_VERSION = 2
 
 if sys.platform.startswith("linux"):
     NOSIGNAL = socket.MSG_NOSIGNAL
@@ -32,7 +32,7 @@ class NetworkClient:
         self.max_protocol_version = OPENRGB_PROTOCOL_VERSION
         if protocol_version is not None:
             if protocol_version > self.max_protocol_version:
-                raise ValueError(f"version {protocol_version} is greater than maximum supported version {self.max_protocol_version}")
+                raise utils.SDKVersionError(f"Requested protocol version {protocol_version} is greater than maximum supported version {self.max_protocol_version}")
             self._protocol_version = protocol_version
         else:
             self._protocol_version = OPENRGB_PROTOCOL_VERSION
@@ -120,9 +120,10 @@ class NetworkClient:
                     except RuntimeError:
                         pass
             elif packet_type == utils.PacketType.REQUEST_CONTROLLER_DATA:
-                data = bytearray(packet_size)
                 try:
-                    self.sock.recv_into(data)
+                    data =  bytearray()
+                    while len(data) < packet_size:
+                        data += self.sock.recv(packet_size - len(data))
                 except utils.CONNECTION_ERRORS as e:
                     self.stop_connection()
                     raise utils.OpenRGBDisconnected() from e
@@ -142,6 +143,17 @@ class NetworkClient:
                     raise utils.OpenRGBDisconnected() from e
                 finally:
                     self.lock.release()
+            elif packet_type == utils.PacketType.REQUEST_PROFILE_LIST:
+                try:
+                    data =  bytearray()
+                    while len(data) < packet_size:
+                        data += self.sock.recv(packet_size - len(data))
+                except utils.CONNECTION_ERRORS as e:
+                    self.stop_connection()
+                    raise utils.OpenRGBDisconnected() from e
+                finally:
+                    self.lock.release()
+                self.callback(device_id, packet_type, utils.parse_list(utils.Profile, data, self._protocol_version, 4)[1])
 
     def requestDeviceData(self, device: int):
         '''
@@ -162,6 +174,10 @@ class NetworkClient:
         self.send_header(0, utils.PacketType.REQUEST_CONTROLLER_COUNT, 0)
         self.read()
 
+    def requestProfileList(self):
+        self.send_header(0, utils.PacketType.REQUEST_PROFILE_LIST, 0)
+        self.read()
+
     def send_header(self, device_id: int, packet_type: int, packet_size: int):
         '''
         Sends a header to the SDK
@@ -172,8 +188,12 @@ class NetworkClient:
         '''
         if self.sock is None:
             raise utils.OpenRGBDisconnected()
-        if packet_size > 0 or packet_type in (utils.PacketType.REQUEST_CONTROLLER_COUNT, utils.PacketType.REQUEST_CONTROLLER_DATA, utils.PacketType.REQUEST_PROTOCOL_VERSION):
+        if packet_size > 0 or packet_type in (utils.PacketType.REQUEST_CONTROLLER_COUNT,\
+                                              utils.PacketType.REQUEST_CONTROLLER_DATA,\
+                                              utils.PacketType.REQUEST_PROTOCOL_VERSION,\
+                                              utils.PacketType.REQUEST_PROFILE_LIST):
             self.lock.acquire()
+
         try:
             self.sock.send(struct.pack('ccccIII', b'O', b'R', b'G', b'B', device_id, packet_type, packet_size), NOSIGNAL)
         except utils.CONNECTION_ERRORS as e:
