@@ -65,6 +65,10 @@ class PacketType(IntEnum):
     REQUEST_PROTOCOL_VERSION = 40
     SET_CLIENT_NAME = 50
     DEVICE_LIST_UPDATED = 100
+    REQUEST_PROFILE_LIST = 150
+    REQUEST_SAVE_PROFILE = 151
+    REQUEST_LOAD_PROFILE = 152
+    REQUEST_DELETE_PROFILE = 153
     RGBCONTROLLER_RESIZEZONE = 1000
     RGBCONTROLLER_UPDATELEDS = 1050
     RGBCONTROLLER_UPDATEZONELEDS = 1051
@@ -77,6 +81,10 @@ class OpenRGBDisconnected(ConnectionError):
     pass
 
 
+class SDKVersionError(NotImplementedError):
+    pass
+
+
 def parse_string(data: bytes, start: int = 0) -> tuple[int, str]:
     '''
     Parses a string based on a size.
@@ -162,6 +170,13 @@ class RGBColor:
         '''
         return cls(*(round(i * 255) for i in colorsys.hsv_to_rgb(hue/360, saturation/100, value/100)))
 
+    @classmethod
+    def fromHEX(cls, hex: str) -> RGBColor:
+        '''
+        Creates a RGBColor object from a hex color string
+        '''
+        return cls(*(int(hex.lstrip('#')[i:i+2], 16) for i in (0, 2, 4)))
+
 
 @dataclass
 class LEDData:
@@ -487,7 +502,7 @@ class ControllerData:
 
 
 @dataclass
-class Profile:
+class LocalProfile:
     '''
     A dataclass to load, store, and pack the data found in an OpenRGB profile file.
     '''
@@ -501,7 +516,7 @@ class Profile:
         return data
 
     @classmethod
-    def unpack(cls, profile: BinaryIO) -> Profile:
+    def unpack(cls, profile: BinaryIO) -> LocalProfile:
         header = profile.read(16 + struct.calcsize("I"))
         if struct.unpack("16s", header[:16])[0] != b"OPENRGB_PROFILE\x00":
             raise ValueError("The file is not an OpenRGB profile")
@@ -519,6 +534,21 @@ class Profile:
             return cls(controllers)
 
 
+@dataclass
+class Profile:
+    '''
+    A simple dataclass to parse profiles from the server.
+    '''
+    name: str
+
+    def pack(self) -> bytearray:
+        return bytearray(f"{self.name}\0", 'utf-8')
+
+    @classmethod
+    def unpack(cls, data: bytearray, version: int, start: int = 0, *args) -> Profile:
+        x, s = parse_string(data, start)
+        return x, cls(s)
+
 class RGBObject:
     '''
     A parent class that includes a few generic functions that use the
